Uses recognized symbols: the mean image row of the white pieces versus the black pieces. Rows are numbered from the top, so the army with the larger mean row is the one on the bottom.
Uses recognized symbols: the mean image row of the white pieces versus the black pieces. Rows are numbered from the top, so the army with the larger mean row is the one on the bottom.