The en-passant square is cleared at the same time: it belongs to the side that was about to move, and is meaningless once the other side is on turn.
The en-passant square is cleared at the same time: it belongs to the side that was about to move, and is meaningless once the other side is on turn.